@@ -15,10 +15,10 @@ HTML::Summary - generate a summary from a web page
  use HTML::Summary;
  use HTML::TreeBuilder;
  
- my $tree = new HTML::TreeBuilder;
+ my $tree = HTML::TreeBuilder->new;
  $tree->parse( $document );
 
- my $summarizer = new HTML::Summary(
+ my $summarizer = HTML::Summary->new(
      LENGTH      => 200,
      USE_META    => 1,
  );
@@ -65,7 +65,7 @@ returned in full, even if it is greater than LENGTH bytes. Default is 0 (no).
 
 =back
 
- my $summarizer = new HTML::Summary LENGTH => 200;
+ my $summarizer = HTML::Summary->new(LENGTH => 200);
 
 =head1 METHODS
 
@@ -80,7 +80,7 @@ Get / set HTML::Summary configuration options.
 
 Takes an HTML::Element object, and generates a summary from it.
 
- my $tree = new HTML::TreeBuilder;
+ my $tree = HTML::TreeBuilder->new;
  $tree->parse( $document );
  my $summary = $summarizer->generate( $tree );
 
@@ -101,7 +101,7 @@ L<Lingua::JA::Jtruncate>.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/HTML-Summary>
+L<https://github.com/neilb/HTML-Summary>
 
 =head1 AUTHORS
 
@@ -162,7 +162,7 @@ use constant IGNORE_TEXT => 1;
 
 use vars qw( $VERSION );
 
-our $VERSION = '0.019';
+our $VERSION = '0.020';
 
 #==============================================================================
 #
@@ -194,7 +194,7 @@ my %DEFAULTS = (
 #------------------------------------------------------------------------------
 #
 # new - constructor. Configuration through "hash" type arguments, i.e.
-# my $abs = new HTML::Summary( VAR1 => 'foo', VAR2 => 'bar' );
+# my $abs = HTML::Summary->new( VAR1 => 'foo', VAR2 => 'bar' );
 #
 #------------------------------------------------------------------------------
 
@@ -462,13 +462,13 @@ sub _get_summary_from_meta
             my $node = shift;
             my $flag = shift;
 
-            if ( $node->tag eq 'meta' )
+            if ($node->tag eq 'meta'
+                && defined($node->attr('name'))
+                && lc( $node->attr('name') ) eq 'description'
+                && defined($node->attr('content')))
             {
-                if ( lc( $node->attr( 'name' ) ) eq 'description' )
-                {
-                    $summary = $node->attr( 'content' );
-                    $summary = undef if $summary eq 'content';
-                }
+                $summary = $node->attr( 'content' );
+                $summary = undef if $summary eq 'content';
                 return 0;
             }
             return 1;
